@@ -26,6 +26,7 @@ import java.io.File;
 import java.io.FileOutputStream;
 import java.io.OutputStreamWriter;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Comparator;
@@ -148,13 +149,26 @@ public class DefaultMetadataGenerator
         {
             File[] files = request.componentDescriptorDirectory.listFiles();
 
+            // Sort the files by name to make the output reproducible
+            Arrays.sort( files, new Comparator<File>()
+            {
+                public int compare( File f1, File f2 )
+                {
+                    return f1.getName().compareTo( f2.getName() );
+                }
+            });
+
+            int added = 0;
             for ( File file : files )
             {
                 if ( file.getName().endsWith( ".xml" ) && !file.getName().equals( "plexus.xml" ) )
                 {
                     componentDescriptors.add( file );
+                    added++;
                 }
             }
+
+            getLogger().info( "Merging " + added + " manually-crafted descriptor file(s)" );
         }
 
         if ( componentDescriptors.size() > 0 )
